@@ -1,6 +1,5 @@
 import sys
 import argparse
-import importlib.metadata
 from pathlib import Path
 
 from graphviz_py.graphviz import execute_graphviz
@@ -9,7 +8,7 @@ from graphviz_py.project import Project
 
 parser = argparse.ArgumentParser(description='graphviz-py diagram builder')
 parser.add_argument('-v', '--version', action='version', version=f'{Project.name()} version: {Project.version()}')
-parser.add_argument('files', type=Path, nargs='+', help='an integer for the accumulator')
+parser.add_argument('files', type=Path, nargs=argparse.ZERO_OR_MORE, help='an integer for the accumulator')
 
 args, unknown = parser.parse_known_args()
 
@@ -19,9 +18,10 @@ def main(_=None):
 
     file_contents = []
 
-    for file in args.files:
-        with open(file) as f:
-            file_contents.append(f.read())
+    if args.files:
+        for file in args.files:
+            with open(file) as f:
+                file_contents.append(f.read())
 
     if len(file_contents) == 0:
         file_contents.append(sys.stdin.read())
